@@ -1,10 +1,10 @@
-__version__ = "0.1.25"
+__version__ = "0.1.26"
 __git_commiter_name__ = "Arnon Yaari"
 __git_commiter_email__ = "arnony@infinidat.com"
-__git_branch__ = '(detached from v0.1.25)'
+__git_branch__ = '(detached from v0.1.26)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = 'ec48d2a1f736f401a100f61442515ece23728f9a'
-__git_head_subject__ = 'Finished release v0.1.25.'
+__git_head_hash__ = '03fb40dc63004642a1ec7c88bfe7d6e10b637dba'
+__git_head_subject__ = 'update homepage'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
